@@ -34,11 +34,11 @@ class KanjiBrowserView : public QWidget, private Ui::KanjiBrowserView
 
   public:
         /**
-         * Constuctor.
+         * Constructor.
          *
          * @param parent parent QWidget
          */
-         KanjiBrowserView( QWidget *parent );
+         explicit KanjiBrowserView( QWidget *parent );
         ~KanjiBrowserView();
 
     /**
@@ -56,7 +56,7 @@ class KanjiBrowserView : public QWidget, private Ui::KanjiBrowserView
 
   signals:
     /**
-     * Emited when the status bar changed.
+     * Emitted when the status bar changed.
      *
      * @param text new text to put in the status bar
      */
@@ -100,7 +100,7 @@ class KanjiBrowserView : public QWidget, private Ui::KanjiBrowserView
 
   private:
     /**
-     * QFont to CSS font style convertion.
+     * QFont to CSS font style conversion.
      *
      * @param font font to be convert
      */
